# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_account_transaction_history.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import get_transaction_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2
from . import account_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2
from . import ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_account_transaction_history.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n5org/xrpl/rpc/v1/get_account_transaction_history.proto\x12\x0forg.xrpl.rpc.v1\x1a%org/xrpl/rpc/v1/get_transaction.proto\x1a\x1dorg/xrpl/rpc/v1/account.proto\x1a\x1corg/xrpl/rpc/v1/ledger.proto\"\xae\x02\n#GetAccountTransactionHistoryRequest\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\x12<\n\x10ledger_specifier\x18\x02 \x01(\x0b\x32 .org.xrpl.rpc.v1.LedgerSpecifierH\x00\x12\x34\n\x0cledger_range\x18\x03 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.LedgerRangeH\x00\x12\x0e\n\x06\x62inary\x18\x04 \x01(\x08\x12\x0f\n\x07\x66orward\x18\x05 \x01(\x08\x12\r\n\x05limit\x18\x06 \x01(\r\x12\'\n\x06marker\x18\x07 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.MarkerB\x08\n\x06ledger\"\x96\x02\n$GetAccountTransactionHistoryResponse\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\x12\x18\n\x10ledger_index_min\x18\x02 \x01(\r\x12\x18\n\x10ledger_index_max\x18\x03 \x01(\r\x12\r\n\x05limit\x18\x04 \x01(\r\x12\'\n\x06marker\x18\x05 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Marker\x12=\n\x0ctransactions\x18\x06 \x03(\x0b\x32\'.org.xrpl.rpc.v1.GetTransactionResponse\x12\x11\n\tvalidated\x18\x07 \x01(\x08\"8\n\x06Marker\x12\x14\n\x0cledger_index\x18\x01 \x01(\r\x12\x18\n\x10\x61\x63\x63ount_sequence\x18\x02 \x01(\rB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2.DESCRIPTOR,])




_GETACCOUNTTRANSACTIONHISTORYREQUEST = _descriptor.Descriptor(
  name='GetAccountTransactionHistoryRequest',
  full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_specifier', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.ledger_specifier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_range', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.ledger_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.binary', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.forward', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.limit', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marker', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.marker', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ledger', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest.ledger',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=175,
  serialized_end=477,
)


_GETACCOUNTTRANSACTIONHISTORYRESPONSE = _descriptor.Descriptor(
  name='GetAccountTransactionHistoryResponse',
  full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index_min', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.ledger_index_min', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index_max', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.ledger_index_max', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.limit', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marker', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.marker', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactions', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.transactions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validated', full_name='org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse.validated', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=758,
)


_MARKER = _descriptor.Descriptor(
  name='Marker',
  full_name='org.xrpl.rpc.v1.Marker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_index', full_name='org.xrpl.rpc.v1.Marker.ledger_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_sequence', full_name='org.xrpl.rpc.v1.Marker.account_sequence', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=760,
  serialized_end=816,
)

_GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['ledger_specifier'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERSPECIFIER
_GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['ledger_range'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERRANGE
_GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['marker'].message_type = _MARKER
_GETACCOUNTTRANSACTIONHISTORYREQUEST.oneofs_by_name['ledger'].fields.append(
  _GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['ledger_specifier'])
_GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['ledger_specifier'].containing_oneof = _GETACCOUNTTRANSACTIONHISTORYREQUEST.oneofs_by_name['ledger']
_GETACCOUNTTRANSACTIONHISTORYREQUEST.oneofs_by_name['ledger'].fields.append(
  _GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['ledger_range'])
_GETACCOUNTTRANSACTIONHISTORYREQUEST.fields_by_name['ledger_range'].containing_oneof = _GETACCOUNTTRANSACTIONHISTORYREQUEST.oneofs_by_name['ledger']
_GETACCOUNTTRANSACTIONHISTORYRESPONSE.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_GETACCOUNTTRANSACTIONHISTORYRESPONSE.fields_by_name['marker'].message_type = _MARKER
_GETACCOUNTTRANSACTIONHISTORYRESPONSE.fields_by_name['transactions'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2._GETTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['GetAccountTransactionHistoryRequest'] = _GETACCOUNTTRANSACTIONHISTORYREQUEST
DESCRIPTOR.message_types_by_name['GetAccountTransactionHistoryResponse'] = _GETACCOUNTTRANSACTIONHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['Marker'] = _MARKER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAccountTransactionHistoryRequest = _reflection.GeneratedProtocolMessageType('GetAccountTransactionHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTTRANSACTIONHISTORYREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_account_transaction_history_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest)
  })
_sym_db.RegisterMessage(GetAccountTransactionHistoryRequest)

GetAccountTransactionHistoryResponse = _reflection.GeneratedProtocolMessageType('GetAccountTransactionHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTTRANSACTIONHISTORYRESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_account_transaction_history_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetAccountTransactionHistoryResponse)
  })
_sym_db.RegisterMessage(GetAccountTransactionHistoryResponse)

Marker = _reflection.GeneratedProtocolMessageType('Marker', (_message.Message,), {
  'DESCRIPTOR' : _MARKER,
  '__module__' : 'org.xrpl.rpc.v1.get_account_transaction_history_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Marker)
  })
_sym_db.RegisterMessage(Marker)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Iterable as typing___Iterable,
    List as typing___List,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Tuple as typing___Tuple,
    Union as typing___Union,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
builtin___str = str
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LedgerSpecifier(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ShortcutValue = typing___NewType('ShortcutValue', builtin___int)
    type___ShortcutValue = ShortcutValue
    class Shortcut(object):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: builtin___int) -> builtin___str: ...
        @classmethod
        def Value(cls, name: builtin___str) -> LedgerSpecifier.ShortcutValue: ...
        @classmethod
        def keys(cls) -> typing___List[builtin___str]: ...
        @classmethod
        def values(cls) -> typing___List[LedgerSpecifier.ShortcutValue]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[builtin___str, LedgerSpecifier.ShortcutValue]]: ...
        SHORTCUT_UNSPECIFIED = typing___cast(LedgerSpecifier.ShortcutValue, 0)
        SHORTCUT_VALIDATED = typing___cast(LedgerSpecifier.ShortcutValue, 1)
        SHORTCUT_CLOSED = typing___cast(LedgerSpecifier.ShortcutValue, 2)
        SHORTCUT_CURRENT = typing___cast(LedgerSpecifier.ShortcutValue, 3)
    SHORTCUT_UNSPECIFIED = typing___cast(LedgerSpecifier.ShortcutValue, 0)
    SHORTCUT_VALIDATED = typing___cast(LedgerSpecifier.ShortcutValue, 1)
    SHORTCUT_CLOSED = typing___cast(LedgerSpecifier.ShortcutValue, 2)
    SHORTCUT_CURRENT = typing___cast(LedgerSpecifier.ShortcutValue, 3)
    type___Shortcut = Shortcut

    shortcut: type___LedgerSpecifier.ShortcutValue = ...
    sequence: builtin___int = ...
    hash: builtin___bytes = ...

    def __init__(self,
        *,
        shortcut : typing___Optional[type___LedgerSpecifier.ShortcutValue] = None,
        sequence : typing___Optional[builtin___int] = None,
        hash : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> LedgerSpecifier: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> LedgerSpecifier: ...
    def HasField(self, field_name: typing_extensions___Literal[u"hash",b"hash",u"ledger",b"ledger",u"sequence",b"sequence",u"shortcut",b"shortcut"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"hash",b"hash",u"ledger",b"ledger",u"sequence",b"sequence",u"shortcut",b"shortcut"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"ledger",b"ledger"]) -> typing_extensions___Literal["shortcut","sequence","hash"]: ...
type___LedgerSpecifier = LedgerSpecifier

class LedgerRange(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ledger_index_min: builtin___int = ...
    ledger_index_max: builtin___int = ...

    def __init__(self,
        *,
        ledger_index_min : typing___Optional[builtin___int] = None,
        ledger_index_max : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> LedgerRange: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> LedgerRange: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"ledger_index_max",b"ledger_index_max",u"ledger_index_min",b"ledger_index_min"]) -> None: ...
type___LedgerRange = LedgerRange

class RawLedgerObject(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ModificationTypeValue = typing___NewType('ModificationTypeValue', builtin___int)
    type___ModificationTypeValue = ModificationTypeValue
    class ModificationType(object):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: builtin___int) -> builtin___str: ...
        @classmethod
        def Value(cls, name: builtin___str) -> RawLedgerObject.ModificationTypeValue: ...
        @classmethod
        def keys(cls) -> typing___List[builtin___str]: ...
        @classmethod
        def values(cls) -> typing___List[RawLedgerObject.ModificationTypeValue]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[builtin___str, RawLedgerObject.ModificationTypeValue]]: ...
        UNSPECIFIED = typing___cast(RawLedgerObject.ModificationTypeValue, 0)
        CREATED = typing___cast(RawLedgerObject.ModificationTypeValue, 1)
        MODIFIED = typing___cast(RawLedgerObject.ModificationTypeValue, 2)
        DELETED = typing___cast(RawLedgerObject.ModificationTypeValue, 3)
    UNSPECIFIED = typing___cast(RawLedgerObject.ModificationTypeValue, 0)
    CREATED = typing___cast(RawLedgerObject.ModificationTypeValue, 1)
    MODIFIED = typing___cast(RawLedgerObject.ModificationTypeValue, 2)
    DELETED = typing___cast(RawLedgerObject.ModificationTypeValue, 3)
    type___ModificationType = ModificationType

    data: builtin___bytes = ...
    key: builtin___bytes = ...
    mod_type: type___RawLedgerObject.ModificationTypeValue = ...
    predecessor: builtin___bytes = ...
    successor: builtin___bytes = ...

    def __init__(self,
        *,
        data : typing___Optional[builtin___bytes] = None,
        key : typing___Optional[builtin___bytes] = None,
        mod_type : typing___Optional[type___RawLedgerObject.ModificationTypeValue] = None,
        predecessor : typing___Optional[builtin___bytes] = None,
        successor : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> RawLedgerObject: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> RawLedgerObject: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data",u"key",b"key",u"mod_type",b"mod_type",u"predecessor",b"predecessor",u"successor",b"successor"]) -> None: ...
type___RawLedgerObject = RawLedgerObject

class RawLedgerObjects(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def objects(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___RawLedgerObject]: ...

    def __init__(self,
        *,
        objects : typing___Optional[typing___Iterable[type___RawLedgerObject]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> RawLedgerObjects: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> RawLedgerObjects: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"objects",b"objects"]) -> None: ...
type___RawLedgerObjects = RawLedgerObjects

class BookSuccessor(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    book_base: builtin___bytes = ...
    first_book: builtin___bytes = ...

    def __init__(self,
        *,
        book_base : typing___Optional[builtin___bytes] = None,
        first_book : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> BookSuccessor: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> BookSuccessor: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"book_base",b"book_base",u"first_book",b"first_book"]) -> None: ...
type___BookSuccessor = BookSuccessor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/submit.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import meta_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_meta__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/submit.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n\x1corg/xrpl/rpc/v1/submit.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1aorg/xrpl/rpc/v1/meta.proto\"\\\n\x18SubmitTransactionRequest\x12\x1a\n\x12signed_transaction\x18\x01 \x01(\x0c\x12\x11\n\tfail_hard\x18\x02 \x01(\x08\x12\x11\n\tclient_ip\x18\x03 \x01(\t\"\x9f\x01\n\x19SubmitTransactionResponse\x12\x39\n\rengine_result\x18\x01 \x01(\x0b\x32\".org.xrpl.rpc.v1.TransactionResult\x12\x1a\n\x12\x65ngine_result_code\x18\x02 \x01(\x03\x12\x1d\n\x15\x65ngine_result_message\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x42\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_meta__pb2.DESCRIPTOR,])




_SUBMITTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='SubmitTransactionRequest',
  full_name='org.xrpl.rpc.v1.SubmitTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_transaction', full_name='org.xrpl.rpc.v1.SubmitTransactionRequest.signed_transaction', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fail_hard', full_name='org.xrpl.rpc.v1.SubmitTransactionRequest.fail_hard', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='org.xrpl.rpc.v1.SubmitTransactionRequest.client_ip', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=169,
)


_SUBMITTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='SubmitTransactionResponse',
  full_name='org.xrpl.rpc.v1.SubmitTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine_result', full_name='org.xrpl.rpc.v1.SubmitTransactionResponse.engine_result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engine_result_code', full_name='org.xrpl.rpc.v1.SubmitTransactionResponse.engine_result_code', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engine_result_message', full_name='org.xrpl.rpc.v1.SubmitTransactionResponse.engine_result_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='org.xrpl.rpc.v1.SubmitTransactionResponse.hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=331,
)

_SUBMITTRANSACTIONRESPONSE.fields_by_name['engine_result'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_meta__pb2._TRANSACTIONRESULT
DESCRIPTOR.message_types_by_name['SubmitTransactionRequest'] = _SUBMITTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['SubmitTransactionResponse'] = _SUBMITTRANSACTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubmitTransactionRequest = _reflection.GeneratedProtocolMessageType('SubmitTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTRANSACTIONREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.submit_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SubmitTransactionRequest)
  })
_sym_db.RegisterMessage(SubmitTransactionRequest)

SubmitTransactionResponse = _reflection.GeneratedProtocolMessageType('SubmitTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTRANSACTIONRESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.submit_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SubmitTransactionResponse)
  })
_sym_db.RegisterMessage(SubmitTransactionResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/ledger.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/ledger.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n\x1corg/xrpl/rpc/v1/ledger.proto\x12\x0forg.xrpl.rpc.v1\"\xe7\x01\n\x0fLedgerSpecifier\x12=\n\x08shortcut\x18\x01 \x01(\x0e\x32).org.xrpl.rpc.v1.LedgerSpecifier.ShortcutH\x00\x12\x12\n\x08sequence\x18\x02 \x01(\rH\x00\x12\x0e\n\x04hash\x18\x03 \x01(\x0cH\x00\"g\n\x08Shortcut\x12\x18\n\x14SHORTCUT_UNSPECIFIED\x10\x00\x12\x16\n\x12SHORTCUT_VALIDATED\x10\x01\x12\x13\n\x0fSHORTCUT_CLOSED\x10\x02\x12\x14\n\x10SHORTCUT_CURRENT\x10\x03\x42\x08\n\x06ledger\"A\n\x0bLedgerRange\x12\x18\n\x10ledger_index_min\x18\x01 \x01(\r\x12\x18\n\x10ledger_index_max\x18\x02 \x01(\r\"\xe6\x01\n\x0fRawLedgerObject\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x43\n\x08mod_type\x18\x03 \x01(\x0e\x32\x31.org.xrpl.rpc.v1.RawLedgerObject.ModificationType\x12\x13\n\x0bpredecessor\x18\x04 \x01(\x0c\x12\x11\n\tsuccessor\x18\x05 \x01(\x0c\"K\n\x10ModificationType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0c\n\x08MODIFIED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\"E\n\x10RawLedgerObjects\x12\x31\n\x07objects\x18\x01 \x03(\x0b\x32 .org.xrpl.rpc.v1.RawLedgerObject\"6\n\rBookSuccessor\x12\x11\n\tbook_base\x18\x01 \x01(\x0c\x12\x12\n\nfirst_book\x18\x02 \x01(\x0c\x42\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
)



_LEDGERSPECIFIER_SHORTCUT = _descriptor.EnumDescriptor(
  name='Shortcut',
  full_name='org.xrpl.rpc.v1.LedgerSpecifier.Shortcut',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_VALIDATED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_CLOSED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_CURRENT', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=168,
  serialized_end=271,
)
_sym_db.RegisterEnumDescriptor(_LEDGERSPECIFIER_SHORTCUT)

_RAWLEDGEROBJECT_MODIFICATIONTYPE = _descriptor.EnumDescriptor(
  name='ModificationType',
  full_name='org.xrpl.rpc.v1.RawLedgerObject.ModificationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODIFIED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=506,
  serialized_end=581,
)
_sym_db.RegisterEnumDescriptor(_RAWLEDGEROBJECT_MODIFICATIONTYPE)


_LEDGERSPECIFIER = _descriptor.Descriptor(
  name='LedgerSpecifier',
  full_name='org.xrpl.rpc.v1.LedgerSpecifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shortcut', full_name='org.xrpl.rpc.v1.LedgerSpecifier.shortcut', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='org.xrpl.rpc.v1.LedgerSpecifier.sequence', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='org.xrpl.rpc.v1.LedgerSpecifier.hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LEDGERSPECIFIER_SHORTCUT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ledger', full_name='org.xrpl.rpc.v1.LedgerSpecifier.ledger',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=50,
  serialized_end=281,
)


_LEDGERRANGE = _descriptor.Descriptor(
  name='LedgerRange',
  full_name='org.xrpl.rpc.v1.LedgerRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_index_min', full_name='org.xrpl.rpc.v1.LedgerRange.ledger_index_min', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index_max', full_name='org.xrpl.rpc.v1.LedgerRange.ledger_index_max', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=348,
)


_RAWLEDGEROBJECT = _descriptor.Descriptor(
  name='RawLedgerObject',
  full_name='org.xrpl.rpc.v1.RawLedgerObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='org.xrpl.rpc.v1.RawLedgerObject.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='org.xrpl.rpc.v1.RawLedgerObject.key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mod_type', full_name='org.xrpl.rpc.v1.RawLedgerObject.mod_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predecessor', full_name='org.xrpl.rpc.v1.RawLedgerObject.predecessor', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='successor', full_name='org.xrpl.rpc.v1.RawLedgerObject.successor', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RAWLEDGEROBJECT_MODIFICATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=581,
)


_RAWLEDGEROBJECTS = _descriptor.Descriptor(
  name='RawLedgerObjects',
  full_name='org.xrpl.rpc.v1.RawLedgerObjects',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='org.xrpl.rpc.v1.RawLedgerObjects.objects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=652,
)


_BOOKSUCCESSOR = _descriptor.Descriptor(
  name='BookSuccessor',
  full_name='org.xrpl.rpc.v1.BookSuccessor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='book_base', full_name='org.xrpl.rpc.v1.BookSuccessor.book_base', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_book', full_name='org.xrpl.rpc.v1.BookSuccessor.first_book', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=654,
  serialized_end=708,
)

_LEDGERSPECIFIER.fields_by_name['shortcut'].enum_type = _LEDGERSPECIFIER_SHORTCUT
_LEDGERSPECIFIER_SHORTCUT.containing_type = _LEDGERSPECIFIER
_LEDGERSPECIFIER.oneofs_by_name['ledger'].fields.append(
  _LEDGERSPECIFIER.fields_by_name['shortcut'])
_LEDGERSPECIFIER.fields_by_name['shortcut'].containing_oneof = _LEDGERSPECIFIER.oneofs_by_name['ledger']
_LEDGERSPECIFIER.oneofs_by_name['ledger'].fields.append(
  _LEDGERSPECIFIER.fields_by_name['sequence'])
_LEDGERSPECIFIER.fields_by_name['sequence'].containing_oneof = _LEDGERSPECIFIER.oneofs_by_name['ledger']
_LEDGERSPECIFIER.oneofs_by_name['ledger'].fields.append(
  _LEDGERSPECIFIER.fields_by_name['hash'])
_LEDGERSPECIFIER.fields_by_name['hash'].containing_oneof = _LEDGERSPECIFIER.oneofs_by_name['ledger']
_RAWLEDGEROBJECT.fields_by_name['mod_type'].enum_type = _RAWLEDGEROBJECT_MODIFICATIONTYPE
_RAWLEDGEROBJECT_MODIFICATIONTYPE.containing_type = _RAWLEDGEROBJECT
_RAWLEDGEROBJECTS.fields_by_name['objects'].message_type = _RAWLEDGEROBJECT
DESCRIPTOR.message_types_by_name['LedgerSpecifier'] = _LEDGERSPECIFIER
DESCRIPTOR.message_types_by_name['LedgerRange'] = _LEDGERRANGE
DESCRIPTOR.message_types_by_name['RawLedgerObject'] = _RAWLEDGEROBJECT
DESCRIPTOR.message_types_by_name['RawLedgerObjects'] = _RAWLEDGEROBJECTS
DESCRIPTOR.message_types_by_name['BookSuccessor'] = _BOOKSUCCESSOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LedgerSpecifier = _reflection.GeneratedProtocolMessageType('LedgerSpecifier', (_message.Message,), {
  'DESCRIPTOR' : _LEDGERSPECIFIER,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LedgerSpecifier)
  })
_sym_db.RegisterMessage(LedgerSpecifier)

LedgerRange = _reflection.GeneratedProtocolMessageType('LedgerRange', (_message.Message,), {
  'DESCRIPTOR' : _LEDGERRANGE,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LedgerRange)
  })
_sym_db.RegisterMessage(LedgerRange)

RawLedgerObject = _reflection.GeneratedProtocolMessageType('RawLedgerObject', (_message.Message,), {
  'DESCRIPTOR' : _RAWLEDGEROBJECT,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.RawLedgerObject)
  })
_sym_db.RegisterMessage(RawLedgerObject)

RawLedgerObjects = _reflection.GeneratedProtocolMessageType('RawLedgerObjects', (_message.Message,), {
  'DESCRIPTOR' : _RAWLEDGEROBJECTS,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.RawLedgerObjects)
  })
_sym_db.RegisterMessage(RawLedgerObjects)

BookSuccessor = _reflection.GeneratedProtocolMessageType('BookSuccessor', (_message.Message,), {
  'DESCRIPTOR' : _BOOKSUCCESSOR,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.BookSuccessor)
  })
_sym_db.RegisterMessage(BookSuccessor)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_ledger_data.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_ledger_data.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n%org/xrpl/rpc/v1/get_ledger_data.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1corg/xrpl/rpc/v1/ledger.proto\"\x8d\x01\n\x14GetLedgerDataRequest\x12\x0e\n\x06marker\x18\x01 \x01(\x0c\x12\x30\n\x06ledger\x18\x02 \x01(\x0b\x32 .org.xrpl.rpc.v1.LedgerSpecifier\x12\x12\n\nend_marker\x18\x03 \x01(\x0c\x12\x11\n\tclient_ip\x18\x04 \x01(\t\x12\x0c\n\x04user\x18\x06 \x01(\t\"\xa3\x01\n\x15GetLedgerDataResponse\x12\x14\n\x0cledger_index\x18\x01 \x01(\r\x12\x13\n\x0bledger_hash\x18\x02 \x01(\x0c\x12\x39\n\x0eledger_objects\x18\x03 \x01(\x0b\x32!.org.xrpl.rpc.v1.RawLedgerObjects\x12\x0e\n\x06marker\x18\x04 \x01(\x0c\x12\x14\n\x0cis_unlimited\x18\x07 \x01(\x08\x42\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2.DESCRIPTOR,])




_GETLEDGERDATAREQUEST = _descriptor.Descriptor(
  name='GetLedgerDataRequest',
  full_name='org.xrpl.rpc.v1.GetLedgerDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='marker', full_name='org.xrpl.rpc.v1.GetLedgerDataRequest.marker', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger', full_name='org.xrpl.rpc.v1.GetLedgerDataRequest.ledger', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_marker', full_name='org.xrpl.rpc.v1.GetLedgerDataRequest.end_marker', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='org.xrpl.rpc.v1.GetLedgerDataRequest.client_ip', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='org.xrpl.rpc.v1.GetLedgerDataRequest.user', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=230,
)


_GETLEDGERDATARESPONSE = _descriptor.Descriptor(
  name='GetLedgerDataResponse',
  full_name='org.xrpl.rpc.v1.GetLedgerDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_index', full_name='org.xrpl.rpc.v1.GetLedgerDataResponse.ledger_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_hash', full_name='org.xrpl.rpc.v1.GetLedgerDataResponse.ledger_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_objects', full_name='org.xrpl.rpc.v1.GetLedgerDataResponse.ledger_objects', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marker', full_name='org.xrpl.rpc.v1.GetLedgerDataResponse.marker', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_unlimited', full_name='org.xrpl.rpc.v1.GetLedgerDataResponse.is_unlimited', index=4,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=396,
)

_GETLEDGERDATAREQUEST.fields_by_name['ledger'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERSPECIFIER
_GETLEDGERDATARESPONSE.fields_by_name['ledger_objects'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._RAWLEDGEROBJECTS
DESCRIPTOR.message_types_by_name['GetLedgerDataRequest'] = _GETLEDGERDATAREQUEST
DESCRIPTOR.message_types_by_name['GetLedgerDataResponse'] = _GETLEDGERDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLedgerDataRequest = _reflection.GeneratedProtocolMessageType('GetLedgerDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERDATAREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_data_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetLedgerDataRequest)
  })
_sym_db.RegisterMessage(GetLedgerDataRequest)

GetLedgerDataResponse = _reflection.GeneratedProtocolMessageType('GetLedgerDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERDATARESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_data_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetLedgerDataResponse)
  })
_sym_db.RegisterMessage(GetLedgerDataResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from .account_pb2 import (
    AccountAddress as org___xrpl___rpc___v1___account_pb2___AccountAddress,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CurrencyAmount(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def xrp_amount(self) -> type___XRPDropsAmount: ...

    @property
    def issued_currency_amount(self) -> type___IssuedCurrencyAmount: ...

    def __init__(self,
        *,
        xrp_amount : typing___Optional[type___XRPDropsAmount] = None,
        issued_currency_amount : typing___Optional[type___IssuedCurrencyAmount] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> CurrencyAmount: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> CurrencyAmount: ...
    def HasField(self, field_name: typing_extensions___Literal[u"amount",b"amount",u"issued_currency_amount",b"issued_currency_amount",u"xrp_amount",b"xrp_amount"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"amount",b"amount",u"issued_currency_amount",b"issued_currency_amount",u"xrp_amount",b"xrp_amount"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"amount",b"amount"]) -> typing_extensions___Literal["xrp_amount","issued_currency_amount"]: ...
type___CurrencyAmount = CurrencyAmount

class XRPDropsAmount(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    drops: builtin___int = ...

    def __init__(self,
        *,
        drops : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> XRPDropsAmount: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> XRPDropsAmount: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"drops",b"drops"]) -> None: ...
type___XRPDropsAmount = XRPDropsAmount

class IssuedCurrencyAmount(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    value: typing___Text = ...

    @property
    def currency(self) -> type___Currency: ...

    @property
    def issuer(self) -> org___xrpl___rpc___v1___account_pb2___AccountAddress: ...

    def __init__(self,
        *,
        currency : typing___Optional[type___Currency] = None,
        value : typing___Optional[typing___Text] = None,
        issuer : typing___Optional[org___xrpl___rpc___v1___account_pb2___AccountAddress] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IssuedCurrencyAmount: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IssuedCurrencyAmount: ...
    def HasField(self, field_name: typing_extensions___Literal[u"currency",b"currency",u"issuer",b"issuer"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"currency",b"currency",u"issuer",b"issuer",u"value",b"value"]) -> None: ...
type___IssuedCurrencyAmount = IssuedCurrencyAmount

class Currency(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    name: typing___Text = ...
    code: builtin___bytes = ...

    def __init__(self,
        *,
        name : typing___Optional[typing___Text] = None,
        code : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> Currency: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Currency: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"code",b"code",u"name",b"name"]) -> None: ...
type___Currency = Currency



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_ledger.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_ledger.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n org/xrpl/rpc/v1/get_ledger.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1corg/xrpl/rpc/v1/ledger.proto\"\xbe\x01\n\x10GetLedgerRequest\x12\x30\n\x06ledger\x18\x01 \x01(\x0b\x32 .org.xrpl.rpc.v1.LedgerSpecifier\x12\x14\n\x0ctransactions\x18\x02 \x01(\x08\x12\x0e\n\x06\x65xpand\x18\x03 \x01(\x08\x12\x13\n\x0bget_objects\x18\x04 \x01(\x08\x12\x11\n\tclient_ip\x18\x05 \x01(\t\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\x1c\n\x14get_object_neighbors\x18\x07 \x01(\x08\"\xb6\x03\n\x11GetLedgerResponse\x12\x15\n\rledger_header\x18\x01 \x01(\x0c\x12;\n\x0bhashes_list\x18\x02 \x01(\x0b\x32$.org.xrpl.rpc.v1.TransactionHashListH\x00\x12H\n\x11transactions_list\x18\x03 \x01(\x0b\x32+.org.xrpl.rpc.v1.TransactionAndMetadataListH\x00\x12\x11\n\tvalidated\x18\x04 \x01(\x08\x12\x39\n\x0eledger_objects\x18\x05 \x01(\x0b\x32!.org.xrpl.rpc.v1.RawLedgerObjects\x12\x19\n\x11skiplist_included\x18\x06 \x01(\x08\x12\x14\n\x0cis_unlimited\x18\x07 \x01(\x08\x12\x18\n\x10objects_included\x18\x08 \x01(\x08\x12!\n\x19object_neighbors_included\x18\t \x01(\x08\x12\x37\n\x0f\x62ook_successors\x18\n \x03(\x0b\x32\x1e.org.xrpl.rpc.v1.BookSuccessorB\x0e\n\x0ctransactions\"%\n\x13TransactionHashList\x12\x0e\n\x06hashes\x18\x01 \x03(\x0c\"I\n\x16TransactionAndMetadata\x12\x18\n\x10transaction_blob\x18\x01 \x01(\x0c\x12\x15\n\rmetadata_blob\x18\x02 \x01(\x0c\"[\n\x1aTransactionAndMetadataList\x12=\n\x0ctransactions\x18\x01 \x03(\x0b\x32\'.org.xrpl.rpc.v1.TransactionAndMetadataB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2.DESCRIPTOR,])




_GETLEDGERREQUEST = _descriptor.Descriptor(
  name='GetLedgerRequest',
  full_name='org.xrpl.rpc.v1.GetLedgerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger', full_name='org.xrpl.rpc.v1.GetLedgerRequest.ledger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactions', full_name='org.xrpl.rpc.v1.GetLedgerRequest.transactions', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expand', full_name='org.xrpl.rpc.v1.GetLedgerRequest.expand', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_objects', full_name='org.xrpl.rpc.v1.GetLedgerRequest.get_objects', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='org.xrpl.rpc.v1.GetLedgerRequest.client_ip', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='org.xrpl.rpc.v1.GetLedgerRequest.user', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_object_neighbors', full_name='org.xrpl.rpc.v1.GetLedgerRequest.get_object_neighbors', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=274,
)


_GETLEDGERRESPONSE = _descriptor.Descriptor(
  name='GetLedgerResponse',
  full_name='org.xrpl.rpc.v1.GetLedgerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_header', full_name='org.xrpl.rpc.v1.GetLedgerResponse.ledger_header', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hashes_list', full_name='org.xrpl.rpc.v1.GetLedgerResponse.hashes_list', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactions_list', full_name='org.xrpl.rpc.v1.GetLedgerResponse.transactions_list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validated', full_name='org.xrpl.rpc.v1.GetLedgerResponse.validated', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_objects', full_name='org.xrpl.rpc.v1.GetLedgerResponse.ledger_objects', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skiplist_included', full_name='org.xrpl.rpc.v1.GetLedgerResponse.skiplist_included', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_unlimited', full_name='org.xrpl.rpc.v1.GetLedgerResponse.is_unlimited', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objects_included', full_name='org.xrpl.rpc.v1.GetLedgerResponse.objects_included', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_neighbors_included', full_name='org.xrpl.rpc.v1.GetLedgerResponse.object_neighbors_included', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='book_successors', full_name='org.xrpl.rpc.v1.GetLedgerResponse.book_successors', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='transactions', full_name='org.xrpl.rpc.v1.GetLedgerResponse.transactions',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=277,
  serialized_end=715,
)


_TRANSACTIONHASHLIST = _descriptor.Descriptor(
  name='TransactionHashList',
  full_name='org.xrpl.rpc.v1.TransactionHashList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hashes', full_name='org.xrpl.rpc.v1.TransactionHashList.hashes', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=754,
)


_TRANSACTIONANDMETADATA = _descriptor.Descriptor(
  name='TransactionAndMetadata',
  full_name='org.xrpl.rpc.v1.TransactionAndMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_blob', full_name='org.xrpl.rpc.v1.TransactionAndMetadata.transaction_blob', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata_blob', full_name='org.xrpl.rpc.v1.TransactionAndMetadata.metadata_blob', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=756,
  serialized_end=829,
)


_TRANSACTIONANDMETADATALIST = _descriptor.Descriptor(
  name='TransactionAndMetadataList',
  full_name='org.xrpl.rpc.v1.TransactionAndMetadataList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactions', full_name='org.xrpl.rpc.v1.TransactionAndMetadataList.transactions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=831,
  serialized_end=922,
)

_GETLEDGERREQUEST.fields_by_name['ledger'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERSPECIFIER
_GETLEDGERRESPONSE.fields_by_name['hashes_list'].message_type = _TRANSACTIONHASHLIST
_GETLEDGERRESPONSE.fields_by_name['transactions_list'].message_type = _TRANSACTIONANDMETADATALIST
_GETLEDGERRESPONSE.fields_by_name['ledger_objects'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._RAWLEDGEROBJECTS
_GETLEDGERRESPONSE.fields_by_name['book_successors'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._BOOKSUCCESSOR
_GETLEDGERRESPONSE.oneofs_by_name['transactions'].fields.append(
  _GETLEDGERRESPONSE.fields_by_name['hashes_list'])
_GETLEDGERRESPONSE.fields_by_name['hashes_list'].containing_oneof = _GETLEDGERRESPONSE.oneofs_by_name['transactions']
_GETLEDGERRESPONSE.oneofs_by_name['transactions'].fields.append(
  _GETLEDGERRESPONSE.fields_by_name['transactions_list'])
_GETLEDGERRESPONSE.fields_by_name['transactions_list'].containing_oneof = _GETLEDGERRESPONSE.oneofs_by_name['transactions']
_TRANSACTIONANDMETADATALIST.fields_by_name['transactions'].message_type = _TRANSACTIONANDMETADATA
DESCRIPTOR.message_types_by_name['GetLedgerRequest'] = _GETLEDGERREQUEST
DESCRIPTOR.message_types_by_name['GetLedgerResponse'] = _GETLEDGERRESPONSE
DESCRIPTOR.message_types_by_name['TransactionHashList'] = _TRANSACTIONHASHLIST
DESCRIPTOR.message_types_by_name['TransactionAndMetadata'] = _TRANSACTIONANDMETADATA
DESCRIPTOR.message_types_by_name['TransactionAndMetadataList'] = _TRANSACTIONANDMETADATALIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLedgerRequest = _reflection.GeneratedProtocolMessageType('GetLedgerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetLedgerRequest)
  })
_sym_db.RegisterMessage(GetLedgerRequest)

GetLedgerResponse = _reflection.GeneratedProtocolMessageType('GetLedgerResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERRESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetLedgerResponse)
  })
_sym_db.RegisterMessage(GetLedgerResponse)

TransactionHashList = _reflection.GeneratedProtocolMessageType('TransactionHashList', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONHASHLIST,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TransactionHashList)
  })
_sym_db.RegisterMessage(TransactionHashList)

TransactionAndMetadata = _reflection.GeneratedProtocolMessageType('TransactionAndMetadata', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONANDMETADATA,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TransactionAndMetadata)
  })
_sym_db.RegisterMessage(TransactionAndMetadata)

TransactionAndMetadataList = _reflection.GeneratedProtocolMessageType('TransactionAndMetadataList', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONANDMETADATALIST,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TransactionAndMetadataList)
  })
_sym_db.RegisterMessage(TransactionAndMetadataList)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_transaction.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import meta_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_meta__pb2
from . import ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2
from . import transaction_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_transaction__pb2
from . import common_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_transaction.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n%org/xrpl/rpc/v1/get_transaction.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1aorg/xrpl/rpc/v1/meta.proto\x1a\x1corg/xrpl/rpc/v1/ledger.proto\x1a!org/xrpl/rpc/v1/transaction.proto\x1a\x1corg/xrpl/rpc/v1/common.proto\"|\n\x15GetTransactionRequest\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0e\n\x06\x62inary\x18\x02 \x01(\x08\x12\x32\n\x0cledger_range\x18\x03 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.LedgerRange\x12\x11\n\tclient_ip\x18\x04 \x01(\t\"\xb2\x02\n\x16GetTransactionResponse\x12\x33\n\x0btransaction\x18\x01 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.TransactionH\x00\x12\x1c\n\x12transaction_binary\x18\x02 \x01(\x0cH\x00\x12\x14\n\x0cledger_index\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x11\n\tvalidated\x18\x05 \x01(\x08\x12%\n\x04meta\x18\x06 \x01(\x0b\x32\x15.org.xrpl.rpc.v1.MetaH\x01\x12\x15\n\x0bmeta_binary\x18\x07 \x01(\x0cH\x01\x12#\n\x04\x64\x61te\x18\x08 \x01(\x0b\x32\x15.org.xrpl.rpc.v1.DateB\x18\n\x16serialized_transactionB\x11\n\x0fserialized_metaB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_meta__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_transaction__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2.DESCRIPTOR,])




_GETTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='GetTransactionRequest',
  full_name='org.xrpl.rpc.v1.GetTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='org.xrpl.rpc.v1.GetTransactionRequest.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='org.xrpl.rpc.v1.GetTransactionRequest.binary', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_range', full_name='org.xrpl.rpc.v1.GetTransactionRequest.ledger_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='org.xrpl.rpc.v1.GetTransactionRequest.client_ip', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=305,
)


_GETTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='GetTransactionResponse',
  full_name='org.xrpl.rpc.v1.GetTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction', full_name='org.xrpl.rpc.v1.GetTransactionResponse.transaction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_binary', full_name='org.xrpl.rpc.v1.GetTransactionResponse.transaction_binary', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index', full_name='org.xrpl.rpc.v1.GetTransactionResponse.ledger_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='org.xrpl.rpc.v1.GetTransactionResponse.hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validated', full_name='org.xrpl.rpc.v1.GetTransactionResponse.validated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta', full_name='org.xrpl.rpc.v1.GetTransactionResponse.meta', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta_binary', full_name='org.xrpl.rpc.v1.GetTransactionResponse.meta_binary', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='org.xrpl.rpc.v1.GetTransactionResponse.date', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='serialized_transaction', full_name='org.xrpl.rpc.v1.GetTransactionResponse.serialized_transaction',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='serialized_meta', full_name='org.xrpl.rpc.v1.GetTransactionResponse.serialized_meta',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=308,
  serialized_end=614,
)

_GETTRANSACTIONREQUEST.fields_by_name['ledger_range'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERRANGE
_GETTRANSACTIONRESPONSE.fields_by_name['transaction'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_transaction__pb2._TRANSACTION
_GETTRANSACTIONRESPONSE.fields_by_name['meta'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_meta__pb2._META
_GETTRANSACTIONRESPONSE.fields_by_name['date'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DATE
_GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_transaction'].fields.append(
  _GETTRANSACTIONRESPONSE.fields_by_name['transaction'])
_GETTRANSACTIONRESPONSE.fields_by_name['transaction'].containing_oneof = _GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_transaction']
_GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_transaction'].fields.append(
  _GETTRANSACTIONRESPONSE.fields_by_name['transaction_binary'])
_GETTRANSACTIONRESPONSE.fields_by_name['transaction_binary'].containing_oneof = _GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_transaction']
_GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_meta'].fields.append(
  _GETTRANSACTIONRESPONSE.fields_by_name['meta'])
_GETTRANSACTIONRESPONSE.fields_by_name['meta'].containing_oneof = _GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_meta']
_GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_meta'].fields.append(
  _GETTRANSACTIONRESPONSE.fields_by_name['meta_binary'])
_GETTRANSACTIONRESPONSE.fields_by_name['meta_binary'].containing_oneof = _GETTRANSACTIONRESPONSE.oneofs_by_name['serialized_meta']
DESCRIPTOR.message_types_by_name['GetTransactionRequest'] = _GETTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['GetTransactionResponse'] = _GETTRANSACTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetTransactionRequest = _reflection.GeneratedProtocolMessageType('GetTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSACTIONREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetTransactionRequest)
  })
_sym_db.RegisterMessage(GetTransactionRequest)

GetTransactionResponse = _reflection.GeneratedProtocolMessageType('GetTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSACTIONRESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetTransactionResponse)
  })
_sym_db.RegisterMessage(GetTransactionResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
import typing as t

from xpring import hashes
from xpring.types import (
    AccountId, Address, EncodedSeed, Seed, PrivateKey, PublicKey, Signature
)
from xpring.algorithms.signing import SigningAlgorithm
from xpring.codec import DEFAULT_CODEC


def derive_account_id(public_key: PublicKey) -> AccountId:
    # https://xrpl.org/accounts.html#address-encoding
    account_id = hashes.ripemd160(hashes.sha256(public_key))
    return t.cast(AccountId, account_id)


@dataclass
class KeyPair:
    seed: Seed
    algorithm: SigningAlgorithm
    private_key: PrivateKey
    public_key: PublicKey

    @classmethod
    def from_encoded_seed(cls, encoded_seed: EncodedSeed) -> 'KeyPair':
        seed, algorithm = DEFAULT_CODEC.decode_seed(encoded_seed)
        private_key, public_key = algorithm.derive_key_pair(seed)
        # TODO: Is this assertion necessary?
        message = b'The quick brown fox jumped over the lazy dog.'
        signature = algorithm.sign(message, private_key)
        if not algorithm.verify(message, signature, public_key):
            raise AssertionError('public key does not verify private key')
        return cls(seed, algorithm, private_key, public_key)

    @property
    def account_id(self) -> AccountId:
        # TODO: cached_property?
        return derive_account_id(self.public_key)

    @property
    def address(self) -> Address:
        return DEFAULT_CODEC.encode_address(self.account_id)

    def sign(self, message: bytes) -> Signature:
        return self.algorithm.sign(message, self.private_key)

    def verify(self, message: bytes, signature: Signature) -> bool:
        return self.algorithm.verify(message, signature, self.public_key)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_ledger_diff.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_ledger_diff.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n%org/xrpl/rpc/v1/get_ledger_diff.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1corg/xrpl/rpc/v1/ledger.proto\"\xb1\x01\n\x14GetLedgerDiffRequest\x12\x35\n\x0b\x62\x61se_ledger\x18\x01 \x01(\x0b\x32 .org.xrpl.rpc.v1.LedgerSpecifier\x12\x38\n\x0e\x64\x65sired_ledger\x18\x02 \x01(\x0b\x32 .org.xrpl.rpc.v1.LedgerSpecifier\x12\x15\n\rinclude_blobs\x18\x03 \x01(\x08\x12\x11\n\tclient_ip\x18\x04 \x01(\t\"R\n\x15GetLedgerDiffResponse\x12\x39\n\x0eledger_objects\x18\x01 \x01(\x0b\x32!.org.xrpl.rpc.v1.RawLedgerObjectsB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2.DESCRIPTOR,])




_GETLEDGERDIFFREQUEST = _descriptor.Descriptor(
  name='GetLedgerDiffRequest',
  full_name='org.xrpl.rpc.v1.GetLedgerDiffRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_ledger', full_name='org.xrpl.rpc.v1.GetLedgerDiffRequest.base_ledger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desired_ledger', full_name='org.xrpl.rpc.v1.GetLedgerDiffRequest.desired_ledger', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='include_blobs', full_name='org.xrpl.rpc.v1.GetLedgerDiffRequest.include_blobs', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='org.xrpl.rpc.v1.GetLedgerDiffRequest.client_ip', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=266,
)


_GETLEDGERDIFFRESPONSE = _descriptor.Descriptor(
  name='GetLedgerDiffResponse',
  full_name='org.xrpl.rpc.v1.GetLedgerDiffResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_objects', full_name='org.xrpl.rpc.v1.GetLedgerDiffResponse.ledger_objects', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=350,
)

_GETLEDGERDIFFREQUEST.fields_by_name['base_ledger'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERSPECIFIER
_GETLEDGERDIFFREQUEST.fields_by_name['desired_ledger'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERSPECIFIER
_GETLEDGERDIFFRESPONSE.fields_by_name['ledger_objects'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._RAWLEDGEROBJECTS
DESCRIPTOR.message_types_by_name['GetLedgerDiffRequest'] = _GETLEDGERDIFFREQUEST
DESCRIPTOR.message_types_by_name['GetLedgerDiffResponse'] = _GETLEDGERDIFFRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLedgerDiffRequest = _reflection.GeneratedProtocolMessageType('GetLedgerDiffRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERDIFFREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_diff_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetLedgerDiffRequest)
  })
_sym_db.RegisterMessage(GetLedgerDiffRequest)

GetLedgerDiffResponse = _reflection.GeneratedProtocolMessageType('GetLedgerDiffResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERDIFFRESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_ledger_diff_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetLedgerDiffResponse)
  })
_sym_db.RegisterMessage(GetLedgerDiffResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from .ledger_pb2 import (
    LedgerSpecifier as org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier,
    RawLedgerObject as org___xrpl___rpc___v1___ledger_pb2___RawLedgerObject,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetLedgerEntryRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    key: builtin___bytes = ...
    client_ip: typing___Text = ...

    @property
    def ledger(self) -> org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier: ...

    def __init__(self,
        *,
        key : typing___Optional[builtin___bytes] = None,
        ledger : typing___Optional[org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier] = None,
        client_ip : typing___Optional[typing___Text] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> GetLedgerEntryRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> GetLedgerEntryRequest: ...
    def HasField(self, field_name: typing_extensions___Literal[u"ledger",b"ledger"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"client_ip",b"client_ip",u"key",b"key",u"ledger",b"ledger"]) -> None: ...
type___GetLedgerEntryRequest = GetLedgerEntryRequest

class GetLedgerEntryResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def ledger_object(self) -> org___xrpl___rpc___v1___ledger_pb2___RawLedgerObject: ...

    @property
    def ledger(self) -> org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier: ...

    def __init__(self,
        *,
        ledger_object : typing___Optional[org___xrpl___rpc___v1___ledger_pb2___RawLedgerObject] = None,
        ledger : typing___Optional[org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> GetLedgerEntryResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> GetLedgerEntryResponse: ...
    def HasField(self, field_name: typing_extensions___Literal[u"ledger",b"ledger",u"ledger_object",b"ledger_object"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"ledger",b"ledger",u"ledger_object",b"ledger_object"]) -> None: ...
type___GetLedgerEntryResponse = GetLedgerEntryResponse



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from .common_pb2 import (
    DeliveredAmount as org___xrpl___rpc___v1___common_pb2___DeliveredAmount,
    PreviousTransactionID as org___xrpl___rpc___v1___common_pb2___PreviousTransactionID,
    PreviousTransactionLedgerSequence as org___xrpl___rpc___v1___common_pb2___PreviousTransactionLedgerSequence,
)

from .ledger_objects_pb2 import (
    LedgerEntryTypeValue as org___xrpl___rpc___v1___ledger_objects_pb2___LedgerEntryTypeValue,
    LedgerObject as org___xrpl___rpc___v1___ledger_objects_pb2___LedgerObject,
)

from typing import (
    Iterable as typing___Iterable,
    List as typing___List,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Text as typing___Text,
    Tuple as typing___Tuple,
    Union as typing___Union,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
builtin___str = str
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SubmitMetadataRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ledger_sequence: builtin___int = ...

    @property
    def affected_nodes(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___AffectedNode]: ...

    def __init__(self,
        *,
        affected_nodes : typing___Optional[typing___Iterable[type___AffectedNode]] = None,
        ledger_sequence : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> SubmitMetadataRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> SubmitMetadataRequest: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"affected_nodes",b"affected_nodes",u"ledger_sequence",b"ledger_sequence"]) -> None: ...
type___SubmitMetadataRequest = SubmitMetadataRequest

class SubmitMetadataResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    success: builtin___bool = ...
    msg: typing___Text = ...

    def __init__(self,
        *,
        success : typing___Optional[builtin___bool] = None,
        msg : typing___Optional[typing___Text] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> SubmitMetadataResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> SubmitMetadataResponse: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"msg",b"msg",u"success",b"success"]) -> None: ...
type___SubmitMetadataResponse = SubmitMetadataResponse

class PrepareLedgerRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ledger_index: builtin___int = ...

    def __init__(self,
        *,
        ledger_index : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> PrepareLedgerRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> PrepareLedgerRequest: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"ledger_index",b"ledger_index"]) -> None: ...
type___PrepareLedgerRequest = PrepareLedgerRequest

class PrepareLedgerResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    success: builtin___bool = ...
    msg: typing___Text = ...

    def __init__(self,
        *,
        success : typing___Optional[builtin___bool] = None,
        msg : typing___Optional[typing___Text] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> PrepareLedgerResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> PrepareLedgerResponse: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"msg",b"msg",u"success",b"success"]) -> None: ...
type___PrepareLedgerResponse = PrepareLedgerResponse

class Meta(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    transaction_index: builtin___int = ...

    @property
    def transaction_result(self) -> type___TransactionResult: ...

    @property
    def affected_nodes(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___AffectedNode]: ...

    @property
    def delivered_amount(self) -> org___xrpl___rpc___v1___common_pb2___DeliveredAmount: ...

    def __init__(self,
        *,
        transaction_index : typing___Optional[builtin___int] = None,
        transaction_result : typing___Optional[type___TransactionResult] = None,
        affected_nodes : typing___Optional[typing___Iterable[type___AffectedNode]] = None,
        delivered_amount : typing___Optional[org___xrpl___rpc___v1___common_pb2___DeliveredAmount] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> Meta: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Meta: ...
    def HasField(self, field_name: typing_extensions___Literal[u"delivered_amount",b"delivered_amount",u"transaction_result",b"transaction_result"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"affected_nodes",b"affected_nodes",u"delivered_amount",b"delivered_amount",u"transaction_index",b"transaction_index",u"transaction_result",b"transaction_result"]) -> None: ...
type___Meta = Meta

class TransactionResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ResultTypeValue = typing___NewType('ResultTypeValue', builtin___int)
    type___ResultTypeValue = ResultTypeValue
    class ResultType(object):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: builtin___int) -> builtin___str: ...
        @classmethod
        def Value(cls, name: builtin___str) -> TransactionResult.ResultTypeValue: ...
        @classmethod
        def keys(cls) -> typing___List[builtin___str]: ...
        @classmethod
        def values(cls) -> typing___List[TransactionResult.ResultTypeValue]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[builtin___str, TransactionResult.ResultTypeValue]]: ...
        RESULT_TYPE_UNSPECIFIED = typing___cast(TransactionResult.ResultTypeValue, 0)
        RESULT_TYPE_TEC = typing___cast(TransactionResult.ResultTypeValue, 1)
        RESULT_TYPE_TEF = typing___cast(TransactionResult.ResultTypeValue, 2)
        RESULT_TYPE_TEL = typing___cast(TransactionResult.ResultTypeValue, 3)
        RESULT_TYPE_TEM = typing___cast(TransactionResult.ResultTypeValue, 4)
        RESULT_TYPE_TER = typing___cast(TransactionResult.ResultTypeValue, 5)
        RESULT_TYPE_TES = typing___cast(TransactionResult.ResultTypeValue, 6)
    RESULT_TYPE_UNSPECIFIED = typing___cast(TransactionResult.ResultTypeValue, 0)
    RESULT_TYPE_TEC = typing___cast(TransactionResult.ResultTypeValue, 1)
    RESULT_TYPE_TEF = typing___cast(TransactionResult.ResultTypeValue, 2)
    RESULT_TYPE_TEL = typing___cast(TransactionResult.ResultTypeValue, 3)
    RESULT_TYPE_TEM = typing___cast(TransactionResult.ResultTypeValue, 4)
    RESULT_TYPE_TER = typing___cast(TransactionResult.ResultTypeValue, 5)
    RESULT_TYPE_TES = typing___cast(TransactionResult.ResultTypeValue, 6)
    type___ResultType = ResultType

    result_type: type___TransactionResult.ResultTypeValue = ...
    result: typing___Text = ...

    def __init__(self,
        *,
        result_type : typing___Optional[type___TransactionResult.ResultTypeValue] = None,
        result : typing___Optional[typing___Text] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> TransactionResult: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> TransactionResult: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"result",b"result",u"result_type",b"result_type"]) -> None: ...
type___TransactionResult = TransactionResult

class AffectedNode(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ledger_entry_type: org___xrpl___rpc___v1___ledger_objects_pb2___LedgerEntryTypeValue = ...
    ledger_index: builtin___bytes = ...

    @property
    def created_node(self) -> type___CreatedNode: ...

    @property
    def deleted_node(self) -> type___DeletedNode: ...

    @property
    def modified_node(self) -> type___ModifiedNode: ...

    def __init__(self,
        *,
        ledger_entry_type : typing___Optional[org___xrpl___rpc___v1___ledger_objects_pb2___LedgerEntryTypeValue] = None,
        ledger_index : typing___Optional[builtin___bytes] = None,
        created_node : typing___Optional[type___CreatedNode] = None,
        deleted_node : typing___Optional[type___DeletedNode] = None,
        modified_node : typing___Optional[type___ModifiedNode] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> AffectedNode: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> AffectedNode: ...
    def HasField(self, field_name: typing_extensions___Literal[u"created_node",b"created_node",u"deleted_node",b"deleted_node",u"modified_node",b"modified_node",u"node",b"node"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"created_node",b"created_node",u"deleted_node",b"deleted_node",u"ledger_entry_type",b"ledger_entry_type",u"ledger_index",b"ledger_index",u"modified_node",b"modified_node",u"node",b"node"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"node",b"node"]) -> typing_extensions___Literal["created_node","deleted_node","modified_node"]: ...
type___AffectedNode = AffectedNode

class CreatedNode(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def new_fields(self) -> org___xrpl___rpc___v1___ledger_objects_pb2___LedgerObject: ...

    def __init__(self,
        *,
        new_fields : typing___Optional[org___xrpl___rpc___v1___ledger_objects_pb2___LedgerObject] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> CreatedNode: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> CreatedNode: ...
    def HasField(self, field_name: typing_extensions___Literal[u"new_fields",b"new_fields"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"new_fields",b"new_fields"]) -> None: ...
type___CreatedNode = CreatedNode

class DeletedNode(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def final_fields(self) -> org___xrpl___rpc___v1___ledger_objects_pb2___LedgerObject: ...

    def __init__(self,
        *,
        final_fields : typing___Optional[org___xrpl___rpc___v1___ledger_objects_pb2___LedgerObject] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DeletedNode: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DeletedNode: ...
    def HasField(self, field_name: typing_extensions___Literal[u"final_fields",b"final_fields"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"final_fields",b"final_fields"]) -> None: ...
type___DeletedNode = DeletedNode

class ModifiedNode(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def final_fields(self) -> org___xrpl___rpc___v1___ledger_objects_pb2___LedgerObject: ...

    @property
    def previous_fields(self) -> org___xrpl___rpc___v1___ledger_objects_pb2___LedgerObject: ...

    @property
    def previous_transaction_id(self) -> org___xrpl___rpc___v1___common_pb2___PreviousTransactionID: ...

    @property
    def previous_transaction_ledger_sequence(self) -> org___xrpl___rpc___v1___common_pb2___PreviousTransactionLedgerSequence: ...

    def __init__(self,
        *,
        final_fields : typing___Optional[org___xrpl___rpc___v1___ledger_objects_pb2___LedgerObject] = None,
        previous_fields : typing___Optional[org___xrpl___rpc___v1___ledger_objects_pb2___LedgerObject] = None,
        previous_transaction_id : typing___Optional[org___xrpl___rpc___v1___common_pb2___PreviousTransactionID] = None,
        previous_transaction_ledger_sequence : typing___Optional[org___xrpl___rpc___v1___common_pb2___PreviousTransactionLedgerSequence] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> ModifiedNode: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> ModifiedNode: ...
    def HasField(self, field_name: typing_extensions___Literal[u"final_fields",b"final_fields",u"previous_fields",b"previous_fields",u"previous_transaction_id",b"previous_transaction_id",u"previous_transaction_ledger_sequence",b"previous_transaction_ledger_sequence"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"final_fields",b"final_fields",u"previous_fields",b"previous_fields",u"previous_transaction_id",b"previous_transaction_id",u"previous_transaction_ledger_sequence",b"previous_transaction_ledger_sequence"]) -> None: ...
type___ModifiedNode = ModifiedNode
